@@ -4,7 +4,7 @@
 
 use {
     crate::{
-        environment::{PyOxidizerSource, PYOXIDIZER_VERSION},
+        environment::{default_target_triple, PYOXIDIZER_VERSION},
         logging, project_building, project_layout, projectmgmt,
     },
     anyhow::{anyhow, Context, Result},
@@ -168,12 +168,12 @@ fn starlark_vars(args: &ArgMatches) -> Result<HashMap<String, Option<String>>> {
 }
 
 pub fn run_cli() -> Result<()> {
-    let source = PyOxidizerSource::default();
+    let mut env = crate::environment::Environment::new()?;
 
     let matches = App::new("PyOxidizer")
         .setting(AppSettings::ArgRequiredElseHelp)
         .version(PYOXIDIZER_VERSION)
-        .long_version(source.version_long().as_str())
+        .long_version(env.pyoxidizer_source.version_long().as_str())
         .author("Gregory Szorc <gregory.szorc@gmail.com>")
         .long_about("Build and distribute Python applications")
         .arg(
@@ -261,7 +261,7 @@ pub fn run_cli() -> Result<()> {
                     Arg::with_name("target_triple")
                         .long("target-triple")
                         .takes_value(true)
-                        .default_value(env!("HOST"))
+                        .default_value(default_target_triple())
                         .help("Target triple of Python distribution to use"),
                 )
                 .arg(
@@ -426,8 +426,6 @@ pub fn run_cli() -> Result<()> {
 
     let logger_context = logging::logger_from_env(log_level);
 
-    let mut env = crate::environment::Environment::new()?;
-
     if matches.is_present("system_rust") {
         env.unmanage_rust().context("unmanaging Rust")?;
     }
