@@ -12,7 +12,8 @@ use {
     python_packaging::{
         interpreter::{
             Allocator, BytesWarning, CheckHashPycsMode, CoerceCLocale, MemoryAllocatorBackend,
-            PythonInterpreterConfig, PythonInterpreterProfile, TerminfoResolution,
+            MultiprocessingStartMethod, PythonInterpreterConfig, PythonInterpreterProfile,
+            TerminfoResolution,
         },
         resource::BytecodeOptimizationLevel,
     },
@@ -127,6 +128,8 @@ pub struct PyembedPythonInterpreterConfig {
     pub filesystem_importer: bool,
     pub packed_resources: Vec<PyembedPackedResourcesSource>,
     pub argvb: bool,
+    pub multiprocessing_auto_dispatch: bool,
+    pub multiprocessing_start_method: MultiprocessingStartMethod,
     pub sys_frozen: bool,
     pub sys_meipass: bool,
     pub terminfo_resolution: TerminfoResolution,
@@ -160,7 +163,9 @@ impl Default for PyembedPythonInterpreterConfig {
             filesystem_importer: false,
             packed_resources: vec![],
             argvb: false,
-            sys_frozen: false,
+            multiprocessing_auto_dispatch: true,
+            multiprocessing_start_method: MultiprocessingStartMethod::Auto,
+            sys_frozen: true,
             sys_meipass: false,
             terminfo_resolution: TerminfoResolution::None,
             tcl_library: None,
@@ -247,6 +252,8 @@ impl PyembedPythonInterpreterConfig {
             extra_extension_modules: None,\n    \
             argv: None,\n    \
             argvb: {},\n    \
+            multiprocessing_auto_dispatch: {},\n    \
+            multiprocessing_start_method: {},\n    \
             sys_frozen: {},\n    \
             sys_meipass: {},\n    \
             terminfo_resolution: {},\n    \
@@ -381,6 +388,19 @@ impl PyembedPythonInterpreterConfig {
                     .join(", ")
             ),
             self.argvb,
+            self.multiprocessing_auto_dispatch,
+            match self.multiprocessing_start_method {
+                MultiprocessingStartMethod::None =>
+                    "pyembed::MultiprocessingStartMethod::None".to_string(),
+                MultiprocessingStartMethod::Fork =>
+                    "pyembed::MultiprocessingStartMethod::Fork".to_string(),
+                MultiprocessingStartMethod::ForkServer =>
+                    "pyembed::MultiprocessingStartMethod::ForkServer".to_string(),
+                MultiprocessingStartMethod::Spawn =>
+                    "pyembed::MultiprocessingStartMethod::Spawn".to_string(),
+                MultiprocessingStartMethod::Auto =>
+                    "pyembed::MultiprocessingStartMethod::Auto".to_string(),
+            },
             self.sys_frozen,
             self.sys_meipass,
             match self.terminfo_resolution {
@@ -423,7 +443,10 @@ impl PyembedPythonInterpreterConfig {
 
 #[cfg(test)]
 mod tests {
-    use crate::py_packaging::distribution::{BinaryLibpythonLinkMode, PythonDistribution};
+    use crate::{
+        environment::default_target_triple,
+        py_packaging::distribution::{BinaryLibpythonLinkMode, PythonDistribution},
+    };
     use {super::*, crate::testutil::*};
 
     fn assert_contains(haystack: &str, needle: &str) -> Result<()> {
@@ -572,17 +595,19 @@ mod tests {
                 )),
             ],
             argvb: true,
-            sys_frozen: true,
+            sys_frozen: false,
             sys_meipass: true,
             terminfo_resolution: TerminfoResolution::Dynamic,
             tcl_library: Some("path".into()),
             write_modules_directory_env: Some("env".into()),
+            multiprocessing_auto_dispatch: false,
+            multiprocessing_start_method: MultiprocessingStartMethod::Spawn,
         };
 
         let builder = dist.as_python_executable_builder(
             &logger,
-            env!("HOST"),
-            env!("HOST"),
+            default_target_triple(),
+            default_target_triple(),
             "all_config_fields",
             BinaryLibpythonLinkMode::Dynamic,
             &policy,
@@ -595,7 +620,7 @@ mod tests {
             &logger,
             "all_config_fields",
             builder.as_ref(),
-            env!("HOST"),
+            default_target_triple(),
             "0",
             false,
         )?;
