@@ -36,11 +36,12 @@ use {
     slog::{info, warn},
     std::{
         collections::{hash_map::RandomState, BTreeMap, HashMap},
+        convert::TryFrom,
         io::{BufRead, BufReader, Read},
         path::{Path, PathBuf},
         sync::Arc,
     },
-    tugger_file_manifest::FileData,
+    tugger_file_manifest::{FileData, FileEntry},
     tugger_licensing::{ComponentFlavor, LicensedComponent},
 };
 
@@ -83,6 +84,31 @@ pub static BROKEN_EXTENSIONS_MACOS: Lazy<Vec<String>> = Lazy::new(|| {
     ]
 });
 
+/// Python modules that we shouldn't generate bytecode for by default.
+///
+/// These are Python modules in the standard library that don't have valid bytecode.
+pub static NO_BYTECODE_MODULES: Lazy<Vec<&'static str>> = Lazy::new(|| {
+    vec![
+        "lib2to3.tests.data.bom",
+        "lib2to3.tests.data.crlf",
+        "lib2to3.tests.data.different_encoding",
+        "lib2to3.tests.data.false_encoding",
+        "lib2to3.tests.data.py2_test_grammar",
+        "lib2to3.tests.data.py3_test_grammar",
+        "test.bad_coding",
+        "test.badsyntax_3131",
+        "test.badsyntax_future3",
+        "test.badsyntax_future4",
+        "test.badsyntax_future5",
+        "test.badsyntax_future6",
+        "test.badsyntax_future7",
+        "test.badsyntax_future8",
+        "test.badsyntax_future9",
+        "test.badsyntax_future10",
+        "test.badsyntax_pep3120",
+    ]
+});
+
 #[derive(Debug, Deserialize)]
 struct LinkEntry {
     name: String,
@@ -430,7 +456,7 @@ pub struct StandaloneDistribution {
     ///
     /// Keys are library names, without the "lib" prefix or file extension.
     /// Values are filesystem paths where library is located.
-    pub libraries: BTreeMap<String, FileData>,
+    pub libraries: BTreeMap<String, PathBuf>,
 
     pub py_modules: BTreeMap<String, PathBuf>,
 
@@ -621,7 +647,7 @@ impl StandaloneDistribution {
         let mut extension_modules: BTreeMap<String, PythonExtensionModuleVariants> =
             BTreeMap::new();
         let mut includes: BTreeMap<String, PathBuf> = BTreeMap::new();
-        let mut libraries: BTreeMap<String, FileData> = BTreeMap::new();
+        let mut libraries = BTreeMap::new();
         let frozen_c: Vec<u8> = Vec::new();
         let mut py_modules: BTreeMap<String, PathBuf> = BTreeMap::new();
         let mut resources: BTreeMap<String, BTreeMap<String, PathBuf>> = BTreeMap::new();
@@ -696,7 +722,9 @@ impl StandaloneDistribution {
             let depends = entry.to_library_dependency(&python_path);
 
             if let Some(p) = &depends.static_library {
-                libraries.insert(depends.name.clone(), p.clone());
+                if let Some(p) = p.backing_path() {
+                    libraries.insert(depends.name.clone(), p.to_path_buf());
+                }
             }
 
             links_core.push(depends);
@@ -756,7 +784,9 @@ impl StandaloneDistribution {
                     let depends = link.to_library_dependency(&python_path);
 
                     if let Some(p) = &depends.static_library {
-                        libraries.insert(depends.name.clone(), p.clone());
+                        if let Some(p) = p.backing_path() {
+                            libraries.insert(depends.name.clone(), p.to_path_buf());
+                        }
                     }
 
                     links.push(depends);
@@ -1236,6 +1266,10 @@ impl PythonDistribution for StandaloneDistribution {
             }
         }
 
+        for name in NO_BYTECODE_MODULES.iter() {
+            policy.register_no_bytecode_module(name);
+        }
+
         Ok(policy)
     }
 
@@ -1372,7 +1406,7 @@ impl PythonDistribution for StandaloneDistribution {
                 .contains(&"shared-library".to_string())
     }
 
-    fn tcl_files(&self) -> Result<Vec<(PathBuf, FileData)>> {
+    fn tcl_files(&self) -> Result<Vec<(PathBuf, FileEntry)>> {
         let mut res = vec![];
 
         if let Some(root) = &self.tcl_library_path {
@@ -1392,7 +1426,7 @@ impl PythonDistribution for StandaloneDistribution {
 
                         let rel_path = path.strip_prefix(&root)?;
 
-                        res.push((rel_path.to_path_buf(), path.into()));
+                        res.push((rel_path.to_path_buf(), FileEntry::try_from(path)?));
                     }
                 }
             }
