@@ -6,16 +6,16 @@ use {
     super::{
         env::{get_context, PyOxidizerEnvironmentContext},
         python_executable::PythonExecutableValue,
-        python_resource::{
-            PythonExtensionModuleValue, PythonModuleSourceValue,
-            PythonPackageDistributionResourceValue, PythonPackageResourceValue,
-        },
+        python_extension_module::PythonExtensionModuleValue,
+        python_module_source::PythonModuleSourceValue,
+        python_package_distribution_resource::PythonPackageDistributionResourceValue,
+        python_package_resource::PythonPackageResourceValue,
     },
     crate::{
         project_building::build_python_executable,
         py_packaging::{binary::PythonBinaryBuilder, resource::AddToFileManifest},
     },
-    anyhow::{Context, Result},
+    anyhow::{anyhow, Context, Result},
     slog::warn,
     starlark::{
         environment::TypeValues,
@@ -29,7 +29,7 @@ use {
             starlark_signature_extraction, starlark_signatures,
         },
     },
-    std::path::Path,
+    std::{ops::DerefMut, path::Path},
     tugger::starlark::file_manifest::FileManifestValue,
     tugger_file_manifest::{FileEntry, FileManifest},
 };
@@ -45,19 +45,18 @@ pub fn file_manifest_add_python_executable(
     release: bool,
     opt_level: &str,
 ) -> Result<()> {
+    const LABEL: &str = "FileManifest.add_python_executable()";
+
     let build = build_python_executable(env, logger, &exe.name(), exe, target, opt_level, release)
         .context("building Python executable")?;
 
-    let content = FileEntry {
-        data: build.exe_data.clone().into(),
-        executable: true,
-    };
+    let content = FileEntry::new_from_data(build.exe_data.clone(), true);
 
     let use_prefix = if prefix == "." { "" } else { prefix };
 
     let path = Path::new(use_prefix).join(build.exe_name);
-    manifest
-        .manifest
+    let mut inner = manifest.inner(LABEL).map_err(|e| anyhow!("{:?}", e))?;
+    inner
         .add_file_entry(&path, content)
         .context("adding exe content to manifest")?;
 
@@ -69,7 +68,8 @@ pub fn file_manifest_add_python_executable(
         extra_files.add_file_entry(&Path::new(use_prefix).join(path), entry.clone())?;
     }
 
-    manifest.manifest.add_manifest(&extra_files)?;
+    inner.add_manifest(&extra_files)?;
+    drop(inner);
 
     // Make the last added Python executable the default run target.
     manifest.run_path = Some(path);
@@ -84,6 +84,8 @@ pub fn file_manifest_add_python_resource(
     prefix: String,
     resource: &Value,
 ) -> ValueResult {
+    const LABEL: &str = "FileManifest.add_python_resource()";
+
     let pyoxidizer_context_value = get_context(type_values)?;
     let pyoxidizer_context = pyoxidizer_context_value
         .downcast_ref::<PyOxidizerEnvironmentContext>()
@@ -92,7 +94,7 @@ pub fn file_manifest_add_python_resource(
     match resource.get_type() {
         "PythonModuleSource" => {
             let m = match resource.downcast_ref::<PythonModuleSourceValue>() {
-                Some(m) => Ok(m.inner.clone()),
+                Some(m) => Ok(m.inner(LABEL)?.m.clone()),
                 None => Err(ValueError::IncorrectParameterType),
             }?;
             warn!(
@@ -100,7 +102,7 @@ pub fn file_manifest_add_python_resource(
                 "adding source module {} to {}", m.name, prefix
             );
 
-            m.add_to_file_manifest(&mut manifest.manifest, &prefix)
+            m.add_to_file_manifest(manifest.inner(LABEL)?.deref_mut(), &prefix)
                 .map_err(|e| {
                     ValueError::from(RuntimeError {
                         code: INCORRECT_PARAMETER_TYPE_ERROR_CODE,
@@ -111,7 +113,7 @@ pub fn file_manifest_add_python_resource(
         }
         "PythonPackageResource" => {
             let m = match resource.downcast_ref::<PythonPackageResourceValue>() {
-                Some(m) => Ok(m.inner.clone()),
+                Some(m) => Ok(m.inner(LABEL)?.r.clone()),
                 None => Err(ValueError::IncorrectParameterType),
             }?;
 
@@ -121,7 +123,7 @@ pub fn file_manifest_add_python_resource(
                 m.symbolic_name(),
                 prefix
             );
-            m.add_to_file_manifest(&mut manifest.manifest, &prefix)
+            m.add_to_file_manifest(manifest.inner(LABEL)?.deref_mut(), &prefix)
                 .map_err(|e| {
                     RuntimeError {
                         code: INCORRECT_PARAMETER_TYPE_ERROR_CODE,
@@ -133,14 +135,14 @@ pub fn file_manifest_add_python_resource(
         }
         "PythonPackageDistributionResource" => {
             let m = match resource.downcast_ref::<PythonPackageDistributionResourceValue>() {
-                Some(m) => Ok(m.inner.clone()),
+                Some(m) => Ok(m.inner(LABEL)?.r.clone()),
                 None => Err(ValueError::IncorrectParameterType),
             }?;
             warn!(
                 pyoxidizer_context.logger(),
                 "adding package distribution resource file {}:{} to {}", m.package, m.name, prefix
             );
-            m.add_to_file_manifest(&mut manifest.manifest, &prefix)
+            m.add_to_file_manifest(manifest.inner(LABEL)?.deref_mut(), &prefix)
                 .map_err(|e| {
                     ValueError::from(RuntimeError {
                         code: INCORRECT_PARAMETER_TYPE_ERROR_CODE,
@@ -151,7 +153,7 @@ pub fn file_manifest_add_python_resource(
         }
         "PythonExtensionModule" => {
             let extension = match resource.downcast_ref::<PythonExtensionModuleValue>() {
-                Some(e) => Ok(e.inner.clone()),
+                Some(e) => Ok(e.inner(LABEL)?.em.clone()),
                 None => Err(ValueError::IncorrectParameterType),
             }?;
 
@@ -160,7 +162,7 @@ pub fn file_manifest_add_python_resource(
                 "adding extension module {} to {}", extension.name, prefix
             );
             extension
-                .add_to_file_manifest(&mut manifest.manifest, &prefix)
+                .add_to_file_manifest(manifest.inner(LABEL)?.deref_mut(), &prefix)
                 .map_err(|e| {
                     ValueError::from(RuntimeError {
                         code: "PYOXIDIZER_BUILD",
@@ -175,7 +177,7 @@ pub fn file_manifest_add_python_resource(
                 warn!(
                     pyoxidizer_context.logger(),
                     "adding Python executable {} to {}",
-                    exe.exe.name(),
+                    exe.inner(LABEL)?.name(),
                     prefix
                 );
                 let exe_manifest_value = exe.to_file_manifest(type_values, prefix)?;
@@ -183,8 +185,8 @@ pub fn file_manifest_add_python_resource(
                     .downcast_ref::<FileManifestValue>()
                     .unwrap();
                 manifest
-                    .manifest
-                    .add_manifest(&exe_manifest.manifest)
+                    .inner(LABEL)?
+                    .add_manifest(&*exe_manifest.inner(LABEL)?)
                     .map_err(|e| {
                         ValueError::from(RuntimeError {
                             code: "PYOXIDIZER_BUILD",
@@ -249,10 +251,7 @@ mod tests {
 
     #[test]
     fn test_add_python_source_module() -> Result<()> {
-        let m = Value::new(FileManifestValue {
-            manifest: FileManifest::default(),
-            run_path: None,
-        });
+        let m = FileManifestValue::new_from_args().unwrap();
 
         let v = Value::new(PythonModuleSourceValue::new(PythonModuleSource {
             name: "foo.bar".to_string(),
@@ -271,28 +270,17 @@ mod tests {
 
         let m = env.get_var("m").unwrap();
         let m = m.downcast_ref::<FileManifestValue>().unwrap();
+        let inner = m.inner("ignored").unwrap();
 
-        let mut entries = m.manifest.iter_entries();
+        let mut entries = inner.iter_entries();
 
         let (p, c) = entries.next().unwrap();
         assert_eq!(p, &PathBuf::from("lib/foo/__init__.py"));
-        assert_eq!(
-            c,
-            &FileEntry {
-                data: vec![].into(),
-                executable: false,
-            }
-        );
+        assert_eq!(c, &vec![].into());
 
         let (p, c) = entries.next().unwrap();
         assert_eq!(p, &PathBuf::from("lib/foo/bar.py"));
-        assert_eq!(
-            c,
-            &FileEntry {
-                data: vec![].into(),
-                executable: false,
-            }
-        );
+        assert_eq!(c, &vec![].into());
 
         assert!(entries.next().is_none());
 
@@ -301,10 +289,7 @@ mod tests {
 
     #[test]
     fn test_add_python_resource_data() -> Result<()> {
-        let m = Value::new(FileManifestValue {
-            manifest: FileManifest::default(),
-            run_path: None,
-        });
+        let m = FileManifestValue::new_from_args().unwrap();
 
         let v = Value::new(PythonPackageResourceValue::new(PythonPackageResource {
             leaf_package: "foo.bar".to_string(),
@@ -322,18 +307,13 @@ mod tests {
 
         let m = env.get_var("m").unwrap();
         let m = m.downcast_ref::<FileManifestValue>().unwrap();
+        let inner = m.inner("ignored").unwrap();
 
-        let mut entries = m.manifest.iter_entries();
+        let mut entries = inner.iter_entries();
         let (p, c) = entries.next().unwrap();
 
         assert_eq!(p, &PathBuf::from("lib/foo/bar/resource.txt"));
-        assert_eq!(
-            c,
-            &FileEntry {
-                data: vec![].into(),
-                executable: false,
-            }
-        );
+        assert_eq!(c, &vec![].into());
 
         assert!(entries.next().is_none());
 
@@ -350,10 +330,7 @@ mod tests {
         let mut env = test_evaluation_context_builder()?.into_context()?;
         add_exe(&mut env)?;
 
-        let m = Value::new(FileManifestValue {
-            manifest: FileManifest::default(),
-            run_path: None,
-        });
+        let m = FileManifestValue::new_from_args().unwrap();
 
         env.set_var("m", m).unwrap();
         env.eval("m.add_python_resource('bin', exe)")?;
@@ -370,10 +347,7 @@ mod tests {
         env.eval("dist = default_python_distribution(python_version='3.8')")?;
         env.eval("exe = dist.to_python_executable('testapp')")?;
 
-        let m = Value::new(FileManifestValue {
-            manifest: FileManifest::default(),
-            run_path: None,
-        });
+        let m = FileManifestValue::new_from_args().unwrap();
 
         env.set_var("m", m).unwrap();
         env.eval("m.add_python_resource('bin', exe)")?;
@@ -386,10 +360,7 @@ mod tests {
         let mut env = test_evaluation_context_builder()?.into_context()?;
         add_exe(&mut env)?;
 
-        let m = Value::new(FileManifestValue {
-            manifest: FileManifest::default(),
-            run_path: None,
-        });
+        let m = FileManifestValue::new_from_args().unwrap();
 
         env.set_var("m", m).unwrap();
 
