@@ -10,11 +10,16 @@ define Oxidized Python binaries.
 
 pub mod env;
 pub mod eval;
+pub mod file;
 pub mod file_resource;
 pub mod python_distribution;
 pub mod python_embedded_resources;
 pub mod python_executable;
+pub mod python_extension_module;
 pub mod python_interpreter_config;
+pub mod python_module_source;
+pub mod python_package_distribution_resource;
+pub mod python_package_resource;
 pub mod python_packaging_policy;
 pub mod python_resource;
 #[cfg(test)]
