@@ -36,7 +36,7 @@ use {
         },
     },
     starlark_dialect_build_targets::{optional_str_arg, optional_type_arg},
-    std::{convert::TryFrom, sync::Arc},
+    std::{convert::TryFrom, ops::Deref, sync::Arc},
 };
 
 /// A Starlark Value wrapper for `PythonDistribution` traits.
@@ -227,11 +227,7 @@ impl PythonDistributionValue {
     ///     packaging_policy=None,
     ///     config=None,
     /// )
-    #[allow(
-        clippy::ptr_arg,
-        clippy::too_many_arguments,
-        clippy::wrong_self_convention
-    )]
+    #[allow(clippy::too_many_arguments, clippy::wrong_self_convention)]
     fn to_python_executable_starlark(
         &mut self,
         type_values: &TypeValues,
@@ -240,6 +236,8 @@ impl PythonDistributionValue {
         packaging_policy: &Value,
         config: &Value,
     ) -> ValueResult {
+        const LABEL: &str = "PythonDistribution.to_python_executable()";
+
         optional_type_arg(
             "packaging_policy",
             "PythonPackagingPolicy",
@@ -337,8 +335,8 @@ impl PythonDistributionValue {
                 &name,
                 // TODO make configurable
                 BinaryLibpythonLinkMode::Default,
-                &policy.inner,
-                &config.inner,
+                policy.inner(LABEL)?.deref(),
+                config.inner(LABEL)?.deref(),
                 host_distribution,
             )
             .map_err(|e| {
@@ -366,8 +364,11 @@ impl PythonDistributionValue {
                 // When we call python_resource_to_value(), the Starlark
                 // callbacks are automatically called.
 
-                let value = python_resource_to_value(&type_values, &mut cs, resource, &policy)
-                    .map_err(|e| anyhow!("error converting PythonResource to Value: {:?}", e))?;
+                let value =
+                    python_resource_to_value(LABEL, &type_values, &mut cs, resource, &policy)
+                        .map_err(|e| {
+                            anyhow!("error converting PythonResource to Value: {:?}", e)
+                        })?;
 
                 let new_add_context = add_context_for_value(&value, "to_python_executable")
                     .map_err(|e| anyhow!("error obtaining add context from Value: {:?}", e))?
@@ -397,20 +398,24 @@ impl PythonDistributionValue {
         type_values: &TypeValues,
         call_stack: &mut CallStack,
     ) -> ValueResult {
+        const LABEL: &str = "PythonDistribution.python_resources()";
+
         let dist = self.resolve_distribution(type_values, "resolve_distribution")?;
         let policy =
             PythonPackagingPolicyValue::new(dist.create_packaging_policy().map_err(|e| {
                 ValueError::from(RuntimeError {
-                    code: "PYOXIDIZER_BUILD",
+                    code: "PYTHON_DISTRIBUTION",
                     message: format!("{:?}", e),
-                    label: "python_resources()".to_string(),
+                    label: LABEL.to_string(),
                 })
             })?);
 
         let values = dist
             .python_resources()
             .iter()
-            .map(|resource| python_resource_to_value(type_values, call_stack, resource, &policy))
+            .map(|resource| {
+                python_resource_to_value(LABEL, type_values, call_stack, resource, &policy)
+            })
             .collect::<Result<Vec<Value>, ValueError>>()?;
 
         Ok(Value::from(values))
@@ -418,7 +423,7 @@ impl PythonDistributionValue {
 }
 
 starlark_module! { python_distribution_module =>
-    #[allow(non_snake_case, clippy::ptr_arg)]
+    #[allow(non_snake_case)]
     PythonDistribution(sha256: String, local_path=NoneType::None, url=NoneType::None, flavor: String = "standalone".to_string()) {
         PythonDistributionValue::from_args(sha256, &local_path, &url, flavor)
     }
@@ -438,7 +443,6 @@ starlark_module! { python_distribution_module =>
         this.python_resources_starlark(&env, cs)
     }
 
-    #[allow(non_snake_case, clippy::ptr_arg)]
     PythonDistribution.to_python_executable(
         env env,
         call_stack cs,
@@ -457,7 +461,6 @@ starlark_module! { python_distribution_module =>
         )
     }
 
-    #[allow(clippy::ptr_arg)]
     default_python_distribution(
         env env,
         flavor: String = "standalone".to_string(),
@@ -471,13 +474,17 @@ starlark_module! { python_distribution_module =>
 #[cfg(test)]
 mod tests {
     use {
-        super::super::python_resource::{
-            PythonExtensionModuleValue, PythonModuleSourceValue, PythonPackageResourceValue,
-        },
-        super::super::testutil::*,
         super::*,
-        crate::py_packaging::distribution::DistributionFlavor,
-        crate::python_distributions::PYTHON_DISTRIBUTIONS,
+        crate::{
+            environment::default_target_triple,
+            py_packaging::distribution::DistributionFlavor,
+            python_distributions::PYTHON_DISTRIBUTIONS,
+            starlark::{
+                python_extension_module::PythonExtensionModuleValue,
+                python_module_source::PythonModuleSourceValue,
+                python_package_resource::PythonPackageResourceValue, testutil::*,
+            },
+        },
     };
 
     #[test]
@@ -487,7 +494,7 @@ mod tests {
 
         let host_distribution = PYTHON_DISTRIBUTIONS
             .find_distribution(
-                crate::project_building::HOST,
+                default_target_triple(),
                 &DistributionFlavor::Standalone,
                 None,
             )
@@ -508,7 +515,7 @@ mod tests {
 
         let wanted = PYTHON_DISTRIBUTIONS
             .find_distribution(
-                crate::project_building::HOST,
+                default_target_triple(),
                 &DistributionFlavor::Standalone,
                 Some("3.8"),
             )
@@ -529,7 +536,7 @@ mod tests {
 
         let wanted = PYTHON_DISTRIBUTIONS
             .find_distribution(
-                crate::project_building::HOST,
+                default_target_triple(),
                 &DistributionFlavor::Standalone,
                 Some("3.9"),
             )
@@ -549,7 +556,7 @@ mod tests {
 
         let host_distribution = PYTHON_DISTRIBUTIONS
             .find_distribution(
-                crate::project_building::HOST,
+                default_target_triple(),
                 &DistributionFlavor::StandaloneDynamic,
                 None,
             )
