@@ -5,15 +5,15 @@
 use {
     super::{
         env::{get_context, PyOxidizerEnvironmentContext},
+        file::FileValue,
         file_resource::file_manifest_add_python_executable,
         python_embedded_resources::PythonEmbeddedResourcesValue,
+        python_extension_module::PythonExtensionModuleValue,
+        python_module_source::PythonModuleSourceValue,
+        python_package_distribution_resource::PythonPackageDistributionResourceValue,
+        python_package_resource::PythonPackageResourceValue,
         python_packaging_policy::PythonPackagingPolicyValue,
-        python_resource::{
-            is_resource_starlark_compatible, python_resource_to_value, FileValue,
-            PythonExtensionModuleValue, PythonModuleSourceValue,
-            PythonPackageDistributionResourceValue, PythonPackageResourceValue,
-            ResourceCollectionContext,
-        },
+        python_resource::{is_resource_starlark_compatible, python_resource_to_value},
     },
     crate::{
         project_building::build_python_executable,
@@ -49,6 +49,7 @@ use {
         io::Write,
         ops::Deref,
         path::{Path, PathBuf},
+        sync::{Arc, Mutex, MutexGuard},
     },
     tugger::starlark::{
         code_signing::{handle_signable_event, SigningAction, SigningContext},
@@ -58,6 +59,7 @@ use {
     },
     tugger_code_signing::SigningDestination,
     tugger_file_manifest::FileData,
+    tugger_wix::target_triple_to_wix_arch,
 };
 
 fn error_context<F, T>(label: &str, f: F) -> Result<T, ValueError>
@@ -73,9 +75,56 @@ where
     })
 }
 
+pub fn build_internal(
+    exe: MutexGuard<Box<dyn PythonBinaryBuilder>>,
+    type_values: &TypeValues,
+    target: &str,
+    context: &PyOxidizerEnvironmentContext,
+) -> Result<(ResolvedTarget, PathBuf)> {
+    // Build an executable by writing out a temporary Rust project
+    // and building it.
+    let build = build_python_executable(
+        context.env(),
+        context.logger(),
+        &exe.name(),
+        &**exe,
+        &context.build_target_triple,
+        &context.build_opt_level,
+        context.build_release,
+    )
+    .context("building Python executable")?;
+
+    let output_path = context
+        .get_output_path(type_values, target)
+        .map_err(|_| anyhow!("unable to resolve output path"))?;
+    let dest_path = output_path.join(build.exe_name);
+    warn!(
+        context.logger(),
+        "writing executable to {}",
+        dest_path.display()
+    );
+    let mut fh =
+        std::fs::File::create(&dest_path).context(format!("creating {}", dest_path.display()))?;
+    fh.write_all(&build.exe_data)
+        .context(format!("writing {}", dest_path.display()))?;
+    tugger_file_manifest::set_executable(&mut fh).context("making binary executable")?;
+
+    Ok((
+        ResolvedTarget {
+            run_mode: RunMode::Path {
+                path: dest_path.clone(),
+            },
+            output_path,
+        },
+        dest_path,
+    ))
+}
+
 /// Represents a builder for a Python executable.
 pub struct PythonExecutableValue {
-    pub exe: Box<dyn PythonBinaryBuilder>,
+    // The non-Starlark API to construct the builder returns a Box<T> and it is
+    // easier to wrap a Box<T> then try to unpack it into an Arc<T>.
+    pub exe: Arc<Mutex<Box<dyn PythonBinaryBuilder>>>,
 
     /// The Starlark Value for the Python packaging policy.
     // This is stored as a Vec because I couldn't figure out how to implement
@@ -87,11 +136,24 @@ pub struct PythonExecutableValue {
 impl PythonExecutableValue {
     pub fn new(exe: Box<dyn PythonBinaryBuilder>, policy: PythonPackagingPolicyValue) -> Self {
         Self {
-            exe,
+            exe: Arc::new(Mutex::new(exe)),
             policy: vec![Value::new(policy)],
         }
     }
 
+    pub fn inner(
+        &self,
+        label: &str,
+    ) -> Result<MutexGuard<Box<dyn PythonBinaryBuilder>>, ValueError> {
+        self.exe.try_lock().map_err(|e| {
+            ValueError::Runtime(RuntimeError {
+                code: "PYTHON_EXECUTABLE",
+                message: format!("failed to acquire lock: {}", e),
+                label: label.to_string(),
+            })
+        })
+    }
+
     /// Obtains a copy of the `PythonPackagingPolicyValue` stored internally.
     pub fn python_packaging_policy(&self) -> PythonPackagingPolicyValue {
         self.policy[0]
@@ -99,51 +161,6 @@ impl PythonExecutableValue {
             .unwrap()
             .clone()
     }
-
-    pub fn build_internal(
-        &self,
-        type_values: &TypeValues,
-        target: &str,
-        context: &PyOxidizerEnvironmentContext,
-    ) -> Result<(ResolvedTarget, PathBuf)> {
-        // Build an executable by writing out a temporary Rust project
-        // and building it.
-        let build = build_python_executable(
-            context.env(),
-            context.logger(),
-            &self.exe.name(),
-            self.exe.deref(),
-            &context.build_target_triple,
-            &context.build_opt_level,
-            context.build_release,
-        )
-        .context("building Python executable")?;
-
-        let output_path = context
-            .get_output_path(type_values, target)
-            .map_err(|_| anyhow!("unable to resolve output path"))?;
-        let dest_path = output_path.join(build.exe_name);
-        warn!(
-            context.logger(),
-            "writing executable to {}",
-            dest_path.display()
-        );
-        let mut fh = std::fs::File::create(&dest_path)
-            .context(format!("creating {}", dest_path.display()))?;
-        fh.write_all(&build.exe_data)
-            .context(format!("writing {}", dest_path.display()))?;
-        tugger_file_manifest::set_executable(&mut fh).context("making binary executable")?;
-
-        Ok((
-            ResolvedTarget {
-                run_mode: RunMode::Path {
-                    path: dest_path.clone(),
-                },
-                output_path,
-            },
-            dest_path,
-        ))
-    }
 }
 
 impl TypedValue for PythonExecutableValue {
@@ -157,18 +174,20 @@ impl TypedValue for PythonExecutableValue {
     }
 
     fn get_attr(&self, attribute: &str) -> ValueResult {
+        let exe = self.inner(&format!("PythonExecutable.{}", attribute))?;
+
         match attribute {
-            "packed_resources_load_mode" => Ok(Value::from(
-                self.exe.packed_resources_load_mode().to_string(),
-            )),
-            "tcl_files_path" => match self.exe.tcl_files_path() {
+            "packed_resources_load_mode" => {
+                Ok(Value::from(exe.packed_resources_load_mode().to_string()))
+            }
+            "tcl_files_path" => match exe.tcl_files_path() {
                 Some(value) => Ok(Value::from(value.to_string())),
                 None => Ok(Value::from(NoneType::None)),
             },
-            "windows_runtime_dlls_mode" => Ok(Value::from(
-                self.exe.windows_runtime_dlls_mode().to_string(),
-            )),
-            "windows_subsystem" => Ok(Value::from(self.exe.windows_subsystem())),
+            "windows_runtime_dlls_mode" => {
+                Ok(Value::from(exe.windows_runtime_dlls_mode().to_string()))
+            }
+            "windows_subsystem" => Ok(Value::from(exe.windows_subsystem())),
             _ => Err(ValueError::OperationNotSupported {
                 op: UnsupportedOperation::GetAttr(attribute.to_string()),
                 left: Self::TYPE.to_string(),
@@ -188,9 +207,11 @@ impl TypedValue for PythonExecutableValue {
     }
 
     fn set_attr(&mut self, attribute: &str, value: Value) -> Result<(), ValueError> {
+        let mut exe = self.inner(&format!("PythonExecutable.{}", attribute))?;
+
         match attribute {
             "packed_resources_load_mode" => {
-                self.exe.set_packed_resources_load_mode(
+                exe.set_packed_resources_load_mode(
                     PackedResourcesLoadMode::try_from(value.to_string().as_str()).map_err(|e| {
                         ValueError::from(RuntimeError {
                             code: INCORRECT_PARAMETER_TYPE_ERROR_CODE,
@@ -203,12 +224,12 @@ impl TypedValue for PythonExecutableValue {
                 Ok(())
             }
             "tcl_files_path" => {
-                self.exe.set_tcl_files_path(value.to_optional());
+                exe.set_tcl_files_path(value.to_optional());
 
                 Ok(())
             }
             "windows_runtime_dlls_mode" => {
-                self.exe.set_windows_runtime_dlls_mode(
+                exe.set_windows_runtime_dlls_mode(
                     WindowsRuntimeDllsMode::try_from(value.to_string().as_str()).map_err(|e| {
                         ValueError::from(RuntimeError {
                             code: INCORRECT_PARAMETER_TYPE_ERROR_CODE,
@@ -221,8 +242,7 @@ impl TypedValue for PythonExecutableValue {
                 Ok(())
             }
             "windows_subsystem" => {
-                self.exe
-                    .set_windows_subsystem(value.to_string().as_str())
+                exe.set_windows_subsystem(value.to_string().as_str())
                     .map_err(|e| {
                         ValueError::from(RuntimeError {
                             code: INCORRECT_PARAMETER_TYPE_ERROR_CODE,
@@ -257,8 +277,10 @@ impl PythonExecutableValue {
             .downcast_ref::<PyOxidizerEnvironmentContext>()
             .ok_or(ValueError::IncorrectParameterType)?;
 
+        let exe = self.inner(LABEL)?;
+
         let (inner, exe_path) = error_context(LABEL, || {
-            self.build_internal(type_values, &target, &pyoxidizer_context)
+            build_internal(exe, type_values, &target, &pyoxidizer_context)
         })?;
 
         let candidate = exe_path.clone().into();
@@ -292,18 +314,24 @@ impl PythonExecutableValue {
         source: String,
         is_package: bool,
     ) -> ValueResult {
+        const LABEL: &str = "PythonExecutable.make_python_module_source()";
+
         let module = PythonModuleSource {
             name,
             source: FileData::Memory(source.into_bytes()),
             is_package,
-            cache_tag: self.exe.cache_tag().to_string(),
+            cache_tag: self.inner(LABEL)?.cache_tag().to_string(),
             is_stdlib: false,
             is_test: false,
         };
 
         let mut value = PythonModuleSourceValue::new(module);
-        self.python_packaging_policy()
-            .apply_to_resource(type_values, call_stack, &mut value)?;
+        self.python_packaging_policy().apply_to_resource(
+            LABEL,
+            type_values,
+            call_stack,
+            &mut value,
+        )?;
 
         Ok(Value::new(value))
     }
@@ -315,6 +343,8 @@ impl PythonExecutableValue {
         call_stack: &mut CallStack,
         args: &Value,
     ) -> ValueResult {
+        const LABEL: &str = "PythonExecutable.pip_download()";
+
         required_list_arg("args", "string", &args)?;
 
         let args: Vec<String> = args.iter()?.iter().map(|x| x.to_string()).collect();
@@ -326,8 +356,10 @@ impl PythonExecutableValue {
 
         let python_packaging_policy = self.python_packaging_policy();
 
+        let mut exe = self.inner(LABEL)?;
+
         let resources = error_context("PythonExecutable.pip_download()", || {
-            self.exe.pip_download(
+            exe.pip_download(
                 pyoxidizer_context.logger(),
                 pyoxidizer_context.verbose,
                 &args,
@@ -337,7 +369,15 @@ impl PythonExecutableValue {
         let resources = resources
             .iter()
             .filter(|r| is_resource_starlark_compatible(r))
-            .map(|r| python_resource_to_value(type_values, call_stack, r, &python_packaging_policy))
+            .map(|r| {
+                python_resource_to_value(
+                    LABEL,
+                    type_values,
+                    call_stack,
+                    r,
+                    &python_packaging_policy,
+                )
+            })
             .collect::<Result<Vec<Value>, ValueError>>()?;
 
         Ok(Value::from(resources))
@@ -351,6 +391,8 @@ impl PythonExecutableValue {
         args: &Value,
         extra_envs: &Value,
     ) -> ValueResult {
+        const LABEL: &str = "PythonExecutable.pip_install()";
+
         required_list_arg("args", "string", &args)?;
         optional_dict_arg("extra_envs", "string", "string", &extra_envs)?;
 
@@ -377,8 +419,10 @@ impl PythonExecutableValue {
 
         let python_packaging_policy = self.python_packaging_policy();
 
-        let resources = error_context("PythonExecutable.pip_install()", || {
-            self.exe.pip_install(
+        let mut exe = self.inner(LABEL)?;
+
+        let resources = error_context(LABEL, || {
+            exe.pip_install(
                 pyoxidizer_context.logger(),
                 pyoxidizer_context.verbose,
                 &args,
@@ -389,7 +433,15 @@ impl PythonExecutableValue {
         let resources = resources
             .iter()
             .filter(|r| is_resource_starlark_compatible(r))
-            .map(|r| python_resource_to_value(type_values, call_stack, r, &python_packaging_policy))
+            .map(|r| {
+                python_resource_to_value(
+                    LABEL,
+                    type_values,
+                    call_stack,
+                    r,
+                    &python_packaging_policy,
+                )
+            })
             .collect::<Result<Vec<Value>, ValueError>>()?;
 
         Ok(Value::from(resources))
@@ -403,6 +455,8 @@ impl PythonExecutableValue {
         path: String,
         packages: &Value,
     ) -> ValueResult {
+        const LABEL: &str = "PythonExecutable.read_package_root()";
+
         required_list_arg("packages", "string", &packages)?;
 
         let packages = packages
@@ -418,15 +472,24 @@ impl PythonExecutableValue {
 
         let python_packaging_policy = self.python_packaging_policy();
 
-        let resources = error_context("PythonExecutable.read_package_root()", || {
-            self.exe
-                .read_package_root(pyoxidizer_context.logger(), Path::new(&path), &packages)
+        let mut exe = self.inner(LABEL)?;
+
+        let resources = error_context(LABEL, || {
+            exe.read_package_root(pyoxidizer_context.logger(), Path::new(&path), &packages)
         })?;
 
         let resources = resources
             .iter()
             .filter(|r| is_resource_starlark_compatible(r))
-            .map(|r| python_resource_to_value(type_values, call_stack, r, &python_packaging_policy))
+            .map(|r| {
+                python_resource_to_value(
+                    LABEL,
+                    type_values,
+                    call_stack,
+                    r,
+                    &python_packaging_policy,
+                )
+            })
             .collect::<Result<Vec<Value>, ValueError>>()?;
 
         Ok(Value::from(resources))
@@ -439,6 +502,8 @@ impl PythonExecutableValue {
         call_stack: &mut CallStack,
         path: String,
     ) -> ValueResult {
+        const LABEL: &str = "PythonExecutable.read_virtualenv()";
+
         let pyoxidizer_context_value = get_context(type_values)?;
         let pyoxidizer_context = pyoxidizer_context_value
             .downcast_ref::<PyOxidizerEnvironmentContext>()
@@ -446,15 +511,24 @@ impl PythonExecutableValue {
 
         let python_packaging_policy = self.python_packaging_policy();
 
-        let resources = error_context("PythonExecutable.read_virtualenv()", || {
-            self.exe
-                .read_virtualenv(pyoxidizer_context.logger(), &Path::new(&path))
+        let mut exe = self.inner(LABEL)?;
+
+        let resources = error_context(LABEL, || {
+            exe.read_virtualenv(pyoxidizer_context.logger(), &Path::new(&path))
         })?;
 
         let resources = resources
             .iter()
             .filter(|r| is_resource_starlark_compatible(r))
-            .map(|r| python_resource_to_value(type_values, call_stack, r, &python_packaging_policy))
+            .map(|r| {
+                python_resource_to_value(
+                    LABEL,
+                    type_values,
+                    call_stack,
+                    r,
+                    &python_packaging_policy,
+                )
+            })
             .collect::<Result<Vec<Value>, ValueError>>()?;
 
         Ok(Value::from(resources))
@@ -469,6 +543,8 @@ impl PythonExecutableValue {
         extra_envs: &Value,
         extra_global_arguments: &Value,
     ) -> ValueResult {
+        const LABEL: &str = "PythonExecutable.setup_py_install()";
+
         optional_dict_arg("extra_envs", "string", "string", &extra_envs)?;
         optional_list_arg("extra_global_arguments", "string", &extra_global_arguments)?;
 
@@ -510,8 +586,10 @@ impl PythonExecutableValue {
 
         let python_packaging_policy = self.python_packaging_policy();
 
-        let resources = error_context("PythonExecutable.setup_py_install()", || {
-            self.exe.setup_py_install(
+        let mut exe = self.inner(LABEL)?;
+
+        let resources = error_context(LABEL, || {
+            exe.setup_py_install(
                 pyoxidizer_context.logger(),
                 &package_path,
                 pyoxidizer_context.verbose,
@@ -523,7 +601,15 @@ impl PythonExecutableValue {
         let resources = resources
             .iter()
             .filter(|r| is_resource_starlark_compatible(r))
-            .map(|r| python_resource_to_value(type_values, call_stack, r, &python_packaging_policy))
+            .map(|r| {
+                python_resource_to_value(
+                    LABEL,
+                    type_values,
+                    call_stack,
+                    r,
+                    &python_packaging_policy,
+                )
+            })
             .collect::<Result<Vec<Value>, ValueError>>()?;
 
         warn!(
@@ -541,14 +627,17 @@ impl PythonExecutableValue {
         label: &str,
         module: &PythonModuleSourceValue,
     ) -> ValueResult {
+        let inner = module.inner(label)?;
+
         info!(
             context.logger(),
-            "adding Python source module {}", module.inner.name;
+            "adding Python source module {}", inner.m.name;
         );
 
+        let mut exe = self.inner(label)?;
+
         error_context(label, || {
-            self.exe
-                .add_python_module_source(&module.inner, module.add_collection_context().clone())
+            exe.add_python_module_source(&inner.m, inner.add_context.clone())
                 .with_context(|| format!("adding {}", module.to_repr()))
         })?;
 
@@ -561,18 +650,18 @@ impl PythonExecutableValue {
         label: &str,
         resource: &PythonPackageResourceValue,
     ) -> ValueResult {
+        let inner = resource.inner(label)?;
+
         info!(
             context.logger(),
             "adding Python package resource {}",
-            resource.inner.symbolic_name()
+            inner.r.symbolic_name()
         );
 
+        let mut exe = self.inner(label)?;
+
         error_context(label, || {
-            self.exe
-                .add_python_package_resource(
-                    &resource.inner,
-                    resource.add_collection_context().clone(),
-                )
+            exe.add_python_package_resource(&inner.r, inner.add_context.clone())
                 .with_context(|| format!("adding {}", resource.to_repr()))
         })?;
 
@@ -585,18 +674,17 @@ impl PythonExecutableValue {
         label: &str,
         resource: &PythonPackageDistributionResourceValue,
     ) -> ValueResult {
+        let inner = resource.inner(label)?;
+
         info!(
             context.logger(),
-            "adding package distribution resource {}:{}",
-            resource.inner.package,
-            resource.inner.name
+            "adding package distribution resource {}:{}", inner.r.package, inner.r.name
         );
+
+        let mut exe = self.inner(label)?;
+
         error_context(label, || {
-            self.exe
-                .add_python_package_distribution_resource(
-                    &resource.inner,
-                    resource.add_collection_context().clone(),
-                )
+            exe.add_python_package_distribution_resource(&inner.r, inner.add_context.clone())
                 .with_context(|| format!("adding {}", resource.to_repr()))
         })?;
 
@@ -609,13 +697,17 @@ impl PythonExecutableValue {
         label: &str,
         module: &PythonExtensionModuleValue,
     ) -> ValueResult {
+        let inner = module.inner(label)?;
+
         info!(
             context.logger(),
-            "adding extension module {}", module.inner.name
+            "adding extension module {}", inner.em.name
         );
+
+        let mut exe = self.inner(label)?;
+
         error_context(label, || {
-            self.exe
-                .add_python_extension_module(&module.inner, module.add_collection_context().clone())
+            exe.add_python_extension_module(&inner.em, inner.add_context.clone())
                 .with_context(|| format!("adding {}", module.to_repr()))
         })?;
 
@@ -628,13 +720,18 @@ impl PythonExecutableValue {
         label: &str,
         file: &FileValue,
     ) -> ValueResult {
+        let inner = file.inner(label)?;
+
         info!(
             context.logger(),
-            "adding file data {}", file.inner.path.display();
+            "adding file data {}",
+            inner.file.path().display()
         );
+
+        let mut exe = self.inner(label)?;
+
         error_context(label, || {
-            self.exe
-                .add_file_data(&file.inner, file.add_collection_context().clone())
+            exe.add_file_data(&inner.file, inner.add_context.clone())
                 .with_context(|| format!("adding {}", file.to_repr()))
         })?;
 
@@ -707,13 +804,17 @@ impl PythonExecutableValue {
 
     /// PythonExecutable.to_embedded_resources()
     pub fn to_embedded_resources(&self) -> ValueResult {
+        const LABEL: &str = "PythonExecutable.to_embedded_resources()";
+
         Ok(Value::new(PythonEmbeddedResourcesValue {
-            exe: self.exe.clone_trait(),
+            exe: self.inner(LABEL)?.clone_trait(),
         }))
     }
 
     /// PythonExecutable.to_file_manifest(prefix)
     pub fn to_file_manifest(&self, type_values: &TypeValues, prefix: String) -> ValueResult {
+        const LABEL: &str = "PythonExecutable.to_file_manifest()";
+
         let pyoxidizer_context_value = get_context(type_values)?;
         let pyoxidizer_context = pyoxidizer_context_value
             .downcast_ref::<PyOxidizerEnvironmentContext>()
@@ -725,13 +826,15 @@ impl PythonExecutableValue {
             .unwrap()
             .unwrap();
 
-        error_context("PythonExecutable.to_file_manifest()", || {
+        let exe = self.inner(LABEL)?;
+
+        error_context(LABEL, || {
             file_manifest_add_python_executable(
                 &mut manifest,
                 pyoxidizer_context.env(),
                 pyoxidizer_context.logger(),
                 &prefix,
-                self.exe.deref(),
+                &**exe,
                 &pyoxidizer_context.build_target_triple,
                 pyoxidizer_context.build_release,
                 &pyoxidizer_context.build_opt_level,
@@ -754,6 +857,8 @@ impl PythonExecutableValue {
         product_manufacturer: String,
         msi_builder_callback: Value,
     ) -> ValueResult {
+        const LABEL: &str = "PythonExecutable.to_wix_bundle_builder()";
+
         optional_type_arg("msi_builder_callback", "function", &msi_builder_callback)?;
 
         let msi_builder_value = self.to_wix_msi_builder(
@@ -780,11 +885,14 @@ impl PythonExecutableValue {
             .downcast_ref::<WiXMsiBuilderValue>()
             .unwrap();
 
+        let arch = target_triple_to_wix_arch(self.inner(LABEL)?.target_triple()).unwrap_or("x64");
+
         let bundle_builder_value = WiXBundleBuilderValue::new_from_args(
             id_prefix,
             product_name,
             product_version,
             product_manufacturer,
+            arch.to_string(),
         )?;
         let mut bundle_builder = bundle_builder_value
             .downcast_mut::<WiXBundleBuilderValue>()
@@ -792,7 +900,7 @@ impl PythonExecutableValue {
             .unwrap();
 
         // Add the VC++ Redistributable for the target platform.
-        match self.exe.target_triple() {
+        match self.inner(LABEL)?.target_triple() {
             "i686-pc-windows-msvc" => {
                 bundle_builder.add_vc_redistributable(type_values, "x86".to_string())?;
             }
@@ -821,14 +929,19 @@ impl PythonExecutableValue {
         product_version: String,
         product_manufacturer: String,
     ) -> ValueResult {
+        const LABEL: &str = "PythonExecutable.to_wix_msi_builder()";
+
         let manifest_value = self.to_file_manifest(type_values, ".".to_string())?;
         let manifest = manifest_value.downcast_ref::<FileManifestValue>().unwrap();
 
+        let arch = target_triple_to_wix_arch(self.inner(LABEL)?.target_triple()).unwrap_or("x64");
+
         let builder_value = WiXMsiBuilderValue::new_from_args(
             id_prefix,
             product_name,
             product_version,
             product_manufacturer,
+            arch.to_string(),
         )?;
         let mut builder = builder_value
             .downcast_mut::<WiXMsiBuilderValue>()
@@ -847,6 +960,8 @@ impl PythonExecutableValue {
         files: &Value,
         glob_files: &Value,
     ) -> ValueResult {
+        const LABEL: &str = "PythonExecutable.filter_resources_from_files()";
+
         optional_list_arg("files", "string", &files)?;
         optional_list_arg("glob_files", "string", &glob_files)?;
 
@@ -874,8 +989,10 @@ impl PythonExecutableValue {
             .downcast_ref::<PyOxidizerEnvironmentContext>()
             .ok_or(ValueError::IncorrectParameterType)?;
 
-        error_context("PythonExecutable.filter_resources_from_files()", || {
-            self.exe.filter_resources_from_files(
+        let mut exe = self.inner(LABEL)?;
+
+        error_context(LABEL, || {
+            exe.filter_resources_from_files(
                 pyoxidizer_context.logger(),
                 &files_refs,
                 &glob_files_refs,
@@ -892,7 +1009,6 @@ starlark_module! { python_executable_env =>
         this.build(env, cs, target)
     }
 
-    #[allow(non_snake_case, clippy::ptr_arg)]
     PythonExecutable.make_python_module_source(
         env env,
         call_stack cs,
@@ -905,7 +1021,6 @@ starlark_module! { python_executable_env =>
         this.make_python_module_source(&env, cs, name, source, is_package)
     }
 
-    #[allow(non_snake_case, clippy::ptr_arg)]
     PythonExecutable.pip_download(
         env env,
         call_stack cs,
@@ -916,7 +1031,6 @@ starlark_module! { python_executable_env =>
         this.pip_download(&env, cs, &args)
     }
 
-    #[allow(non_snake_case, clippy::ptr_arg)]
     PythonExecutable.pip_install(
         env env,
         call_stack cs,
@@ -928,7 +1042,6 @@ starlark_module! { python_executable_env =>
         this.pip_install(&env, cs, &args, &extra_envs)
     }
 
-    #[allow(non_snake_case, clippy::ptr_arg)]
     PythonExecutable.read_package_root(
         env env,
         call_stack cs,
@@ -940,7 +1053,6 @@ starlark_module! { python_executable_env =>
         this.read_package_root(&env, cs, path, &packages)
     }
 
-    #[allow(non_snake_case, clippy::ptr_arg)]
     PythonExecutable.read_virtualenv(
         env env,
         call_stack cs,
@@ -951,7 +1063,6 @@ starlark_module! { python_executable_env =>
         this.read_virtualenv(&env, cs, path)
     }
 
-    #[allow(non_snake_case, clippy::ptr_arg)]
     PythonExecutable.setup_py_install(
         env env,
         call_stack cs,
@@ -964,7 +1075,6 @@ starlark_module! { python_executable_env =>
         this.setup_py_install(&env, cs, package_path, &extra_envs, &extra_global_arguments)
     }
 
-    #[allow(non_snake_case, clippy::ptr_arg)]
     PythonExecutable.add_python_resource(
         env env,
         this,
@@ -978,7 +1088,6 @@ starlark_module! { python_executable_env =>
         )
     }
 
-    #[allow(non_snake_case, clippy::ptr_arg)]
     PythonExecutable.add_python_resources(
         env env,
         this,
@@ -991,7 +1100,6 @@ starlark_module! { python_executable_env =>
         )
     }
 
-    #[allow(clippy::ptr_arg)]
     PythonExecutable.filter_resources_from_files(
         env env,
         this,
@@ -1002,7 +1110,6 @@ starlark_module! { python_executable_env =>
         this.filter_resources_from_files(&env, &files, &glob_files)
     }
 
-    #[allow(clippy::ptr_arg)]
     PythonExecutable.to_embedded_resources(this) {
         let this = this.downcast_ref::<PythonExecutableValue>().unwrap();
         this.to_embedded_resources()
@@ -1062,12 +1169,11 @@ mod tests {
         assert_eq!(exe.get_type(), "PythonExecutable");
 
         let exe = exe.downcast_ref::<PythonExecutableValue>().unwrap();
-        assert!(exe
-            .exe
+        let inner = exe.inner("ignored").unwrap();
+        assert!(inner
             .iter_resources()
             .any(|(_, r)| r.in_memory_source.is_some()));
-        assert!(exe
-            .exe
+        assert!(inner
             .iter_resources()
             .all(|(_, r)| r.in_memory_resources.is_none()));
 
@@ -1087,8 +1193,8 @@ mod tests {
         assert_eq!(exe.get_type(), "PythonExecutable");
 
         let exe = exe.downcast_ref::<PythonExecutableValue>().unwrap();
-        assert!(exe
-            .exe
+        let inner = exe.inner("ignored").unwrap();
+        assert!(inner
             .iter_resources()
             .all(|(_, r)| r.in_memory_source.is_none()));
 
@@ -1157,7 +1263,8 @@ mod tests {
             let v = it.next().unwrap();
             assert_eq!(v.get_type(), PythonModuleSourceValue::TYPE);
             let x = v.downcast_ref::<PythonModuleSourceValue>().unwrap();
-            assert!(x.inner.package().starts_with("pyflakes"));
+            let inner = x.inner("ignored").unwrap();
+            assert!(inner.m.package().starts_with("pyflakes"));
         }
 
         Ok(())
@@ -1181,8 +1288,9 @@ mod tests {
         let v = it.next().unwrap();
         assert_eq!(v.get_type(), PythonModuleSourceValue::TYPE);
         let x = v.downcast_ref::<PythonModuleSourceValue>().unwrap();
-        assert_eq!(x.inner.name, "pyflakes");
-        assert!(x.inner.is_package);
+        let inner = x.inner("ignored").unwrap();
+        assert_eq!(inner.m.name, "pyflakes");
+        assert!(inner.m.is_package);
 
         Ok(())
     }
@@ -1228,16 +1336,20 @@ mod tests {
         let v = it.next().unwrap();
         assert_eq!(v.get_type(), PythonModuleSourceValue::TYPE);
         let x = v.downcast_ref::<PythonModuleSourceValue>().unwrap();
-        assert_eq!(x.inner.name, "bar");
-        assert!(x.inner.is_package);
-        assert_eq!(x.inner.source.resolve().unwrap(), b"# bar");
+        let inner = x.inner("ignored").unwrap();
+        assert_eq!(inner.m.name, "bar");
+        assert!(inner.m.is_package);
+        assert_eq!(inner.m.source.resolve_content().unwrap(), b"# bar");
+        drop(inner);
 
         let v = it.next().unwrap();
         assert_eq!(v.get_type(), PythonModuleSourceValue::TYPE);
         let x = v.downcast_ref::<PythonModuleSourceValue>().unwrap();
-        assert_eq!(x.inner.name, "foo");
-        assert!(!x.inner.is_package);
-        assert_eq!(x.inner.source.resolve().unwrap(), b"# foo");
+        let inner = x.inner("ignored").unwrap();
+        assert_eq!(inner.m.name, "foo");
+        assert!(!inner.m.is_package);
+        assert_eq!(inner.m.source.resolve_content().unwrap(), b"# foo");
+        drop(inner);
 
         Ok(())
     }
@@ -1332,7 +1444,11 @@ mod tests {
 
         assert_eq!(builder.build_msis.len(), 1);
         let mut writer = xml::EventWriter::new(vec![]);
-        builder.build_msis[0].inner.write_xml(&mut writer)?;
+        builder.build_msis[0]
+            .inner("ignored")
+            .unwrap()
+            .builder
+            .write_xml(&mut writer)?;
 
         let xml = String::from_utf8(writer.into_inner())?;
         assert!(xml.find("Description=\"description\"").is_some());
